normalize_tool_ref

Function normalize_tool_ref 

pub fn normalize_tool_ref(value: &str) -> Option<String>
Normalizes a tool reference to a standard tool name.

Returns None if the tool name is not recognized.